.. oHySEM documentation master file, created by Andres Ramos

Contact Us
==========

.. image:: ../img/Escudo.png
   :scale: 70%
   :align: right

.. image:: ../img/logoIIT.png
   :scale: 15%
   :align: right

`Andrés Ramos <https://pascua.iit.comillas.edu/aramos/Ramos_CV.htm>`_ 

andres.ramos@comillas.edu

Universidad Pontificia Comillas

Instituto de Investigación Tecnológica

Alberto Aguilera 23

28015 Madrid, Spain
